@@ -1,11 +1,11 @@
 #
-# $Id: Metabrik.pm,v 13f84766fbc9 2015/01/04 12:08:22 gomor $
+# $Id: Metabrik.pm,v 0ef34b7a9b91 2015/01/22 06:59:40 gomor $
 #
 package Metabrik;
 use strict;
 use warnings;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use base qw(Class::Gomor::Hash);
 
@@ -30,7 +30,7 @@ sub brik_version {
 
 sub brik_properties {
    return {
-      revision => '$Revision: 13f84766fbc9 $',
+      revision => '$Revision: 0ef34b7a9b91 $',
       tags => [ qw() ],
       attributes => {
          debug => [ qw(0|1) ],
@@ -89,7 +89,7 @@ sub brik_help_set {
 
    my $classes = $self->brik_classes;
 
-   for my $class (@$classes) {
+   for my $class (reverse @$classes) {
       my $attributes = $class->brik_attributes;
 
       if (exists($attributes->{$attribute})) {
@@ -116,7 +116,7 @@ sub brik_help_run {
 
    my $classes = $self->brik_classes;
 
-   for my $class (@$classes) {
+   for my $class (reverse @$classes) {
       my $commands = $class->brik_commands;
 
       if (exists($commands->{$command})) {
@@ -481,6 +481,7 @@ sub brik_set_default_attributes {
 
    my $classes = $self->brik_classes;
 
+   # Set default Attributes from brik_properties hierarchy
    for my $class (@$classes) {
       # brik_properties() is the general value to use for the default_attributes
       if (exists($class->brik_properties->{attributes_default})) {
@@ -491,10 +492,13 @@ sub brik_set_default_attributes {
       }
    }
 
-   # Then we look at standard default attributes
+   # Set default Attributes from brik_use_properties, no hierarchy, just inheritance
+   my $class = $self->brik_class;
    if ($self->can('brik_use_properties') && exists($self->brik_use_properties->{attributes_default})) {
       for my $attribute (keys %{$self->brik_use_properties->{attributes_default}}) {
          #next unless defined($self->$attribute); # Do not overwrite if set on new
+         # Do not overwrite if Attribute is set by brik_properties
+         next if exists($class->brik_properties->{attributes_default}->{$attribute});
          $self->$attribute($self->brik_use_properties->{attributes_default}->{$attribute});
       }
    }
@@ -625,7 +629,7 @@ sub brik_check_require_binaries {
    my $error = 0;
    for my $binary (keys %binaries_found) {
       if (! $binaries_found{$binary}) {
-         $self->_log_error("brik_check_require_modules: binary [$binary] not found in \$PATH");
+         $self->_log_error("brik_check_require_binaries: binary [$binary] not found in \$PATH");
          $error++;
       }
    }
@@ -816,6 +820,34 @@ sub brik_has_attribute {
 sub brik_preinit {
    my $self = shift;
 
+   if ($self->brik_has_attribute('datadir')) {
+      my $datadir = $self->datadir;
+
+      my $dir;
+      # If datadir is set by user, we use it blindly.
+      # Usually, only core::global will have it set.
+      if (defined($datadir)) {
+         $dir = $datadir;
+      }
+      # Else, we build it.
+      else {
+         my $global_datadir = $self->global->datadir;
+         $dir = $global_datadir;
+
+         (my $subdir = $self->brik_name) =~ s/::/-/g;
+         if (length($subdir)) {
+            $dir .= '/'.$subdir;
+         }
+
+         $self->datadir($dir);
+      }
+
+      if (! -d $dir) {
+         mkdir($dir)
+            or return $self->_log_error("brik_preinit: mkdir [$dir] failed: $!");
+      }
+   }
+
    return $self;
 }
 
@@ -841,7 +873,7 @@ sub brik_fini {
 sub DESTROY {
    my $self = shift;
 
-   return $self->brik_fini;
+   return $self->brik_fini(@_);
 }
 
 1;
