@@ -1,5 +1,5 @@
 #
-# $Id: Shell.pm,v 13f84766fbc9 2015/01/04 12:08:22 gomor $
+# $Id: Shell.pm,v 7b2aed5215f7 2015/02/10 07:01:25 gomor $
 #
 # core::shell Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Core::Shell;
 use strict;
 use warnings;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use base qw(Term::Shell Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 13f84766fbc9 $',
+      revision => '$Revision: 7b2aed5215f7 $',
       tags => [ qw(core main shell) ],
       attributes => {
          echo => [ qw(0|1) ],
@@ -59,6 +59,7 @@ sub brik_properties {
          'Data::Dump' => [ qw(dump) ],
          'File::HomeDir' => [ ],
          'Cwd' => [ ],
+         'PPI' => [ ],
       },
    };
 }
@@ -93,10 +94,8 @@ sub brik_init {
    if ($context->is_used('shell::rc')) {
       $self->debug && $self->log->debug("brik_init: load rc file");
 
-      my $cmd = $context->run('shell::rc', 'load');
-      for (@$cmd) {
-         $self->cmd($_);
-      }
+      my $lines = $context->run('shell::rc', 'load');
+      $self->cmdloop($lines);
    }
 
    $self->debug && $self->log->debug("brik_init: done");
@@ -275,33 +274,108 @@ sub prompt_str {
    return $self->{prompt};
 }
 
+sub cmd_is_complete {
+   my $self = shift;
+   my ($lines) = @_;
+
+   my $string = join("\n", @$lines);
+
+   my $document = PPI::Document->new(\$string);
+   if (! $document) {
+      return $self->log->error("cmd_complete: cannot parse Perl string");
+   }
+
+   # Courtesy of Perl::Shell complete() function
+   my $r = $document->find_any(sub {
+      $_[1]->isa('PPI::Structure') and ! $_[1]->finish
+   });
+
+   return $r ? 0 : 1;
+}
+
+sub cmd_to_code {
+   my $self = shift;
+   my ($line) = @_;
+
+   if ($line =~ /^\s*set\s+/
+   ||  $line =~ /^\s*get\s+/
+   ||  $line =~ /^\s*use\s+/
+   ||  $line =~ /^\s*run\s+/) {
+      $line =~ s/^\s*(.*)\s*$/\$SHE->cmd("$1");/;
+      $self->debug && $self->log->debug("cmd_to_code: [$line]");
+   }
+
+   return $line;
+}
+
+sub process_line {
+   my $self = shift;
+   my ($line, $lines) = @_;
+
+   $self->debug && $self->log->debug("process_line: [$line]");
+
+   # Skip comments
+   if ($line =~ /^\s*#/) {
+      return 0;
+   }
+   # Skip blank lines
+   if ($line =~ /^\s*$/) {
+      return 0;
+   }
+
+   push @$lines, $line;
+
+   # If a closure is open, we are in multiline mode
+   if (! $self->cmd_is_complete($lines)) {
+      # If it looks like a Metabrik command, we rewrite it to a Perl code string
+      $lines->[-1] = $self->cmd_to_code($line);
+      $self->_update_prompt('.. ');
+      return 1;
+   }
+
+   $self->debug && $self->log->debug("cmdloop: lines[@$lines]");
+
+   $self->cmd(join('', @$lines));
+
+   $self->_update_prompt;
+
+   return 0;
+}
+
 sub cmdloop {
    my $self = shift;
+   my ($lines) = @_;
 
    $self->{stop} = 0;
    $self->preloop;
 
    my @lines = ();
-   while (defined(my $line = $self->readline($self->prompt_str))) {
-      push @lines, $line;
 
-      if ($line =~ /\\\s*$/) {
-         $self->_update_prompt('.. ');
-         next;
+   # User provided lines to execute (script)
+   if (defined($lines)) {
+      for my $line (@$lines) {
+         if ($self->process_line($line, \@lines)) {
+            next;   # We are in multiline mode
+         }
+         else {
+            @lines = ();  # Command is complete, we ran it and now reset line buffer.
+         }
+
+         last if $self->{stop};
       }
+   }
+   # Or we are in interactive mode (shell)
+   else {
+      while (defined(my $line = $self->readline($self->prompt_str))) {
+         if ($self->process_line($line, \@lines)) {
+            next;   # We are in multiline mode
+         }
+         else {
+            @lines = ();  # Command is complete, we ran it and now reset line buffer.
+         }
 
-      # Multiline edition finished, we can remove the `\' char before joining
-      for (@lines) {
-         s/\\\s*$//;
+         last if $self->{stop};
       }
-
-      $self->debug && $self->log->debug("cmdloop: lines[@lines]");
-
-      $self->cmd(join('', @lines));
-      @lines = ();
-      $self->_update_prompt;
-
-      last if $self->{stop};
    }
 
    $self->run_exit;
