@@ -1,5 +1,5 @@
 #
-# $Id: Command.pm,v 13f84766fbc9 2015/01/04 12:08:22 gomor $
+# $Id: Command.pm,v 100d172795ff 2015/01/19 06:44:55 gomor $
 #
 # shell::command Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::Command;
 use strict;
 use warnings;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 13f84766fbc9 $',
+      revision => '$Revision: 100d172795ff $',
       tags => [ qw(main shell command system) ],
       attributes => {
          as_array => [ qw(0|1) ],
@@ -76,6 +76,11 @@ sub capture {
    #}
 
    my $out = $self->capture_stderr ? `$run 2>&1` : `$run`;
+   $out ||= 'undef';
+   chomp($out);
+   if ($?) {
+      return $self->log->error("capture: exec failed [$out]");
+   }
 
    # as_matrix has precedence over as_array (because as_array is the default)
    if (! $self->as_matrix && $self->as_array) {
