@@ -1,5 +1,5 @@
 #
-# $Id: Rc.pm,v 13f84766fbc9 2015/01/04 12:08:22 gomor $
+# $Id: Rc.pm,v 7b2aed5215f7 2015/02/10 07:01:25 gomor $
 #
 # shell::rc Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::Rc;
 use strict;
 use warnings;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 13f84766fbc9 $',
+      revision => '$Revision: 7b2aed5215f7 $',
       tags => [ qw(main shell rc) ],
       attributes => {
          rc_file => [ qw(file) ],
@@ -51,31 +51,10 @@ sub load {
    }
 
    my @lines = ();
-   my @multilines = ();
    open(my $in, '<', $rc_file)
          or return $self->log->error("local: can't open rc file [$rc_file]: $!");
-   while (defined(my $this = <$in>)) {
-      chomp($this);
-      next if ($this =~ /^\s*#/);  # Skip comments
-      next if ($this =~ /^\s*$/);  # Skip blank lines
-
-      push @multilines, $this;
-
-      # First line of a multiline
-      if ($this =~ /\\\s*$/) {
-         next;
-      }
-
-      # Multiline edition finished, we can remove the `\' char before joining
-      for (@multilines) {
-         s/\\\s*$//;
-      }
-
-      $self->debug && $self->log->debug("load: multilines[@multilines]");
-
-      my $line = join('', @multilines);
-      @multilines = ();
-
+   while (defined(my $line = <$in>)) {
+      chomp($line);
       push @lines, $line;
    }
    close($in);
