@@ -1,5 +1,5 @@
 #
-# $Id: Script.pm,v 13f84766fbc9 2015/01/04 12:08:22 gomor $
+# $Id: Script.pm,v 7b2aed5215f7 2015/02/10 07:01:25 gomor $
 #
 # shell::script Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::Script;
 use strict;
 use warnings;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 13f84766fbc9 $',
+      revision => '$Revision: 7b2aed5215f7 $',
       tags => [ qw(main shell script) ],
       attributes => {
          file => [ qw(file) ],
@@ -39,10 +39,8 @@ sub brik_init {
    if ($context->is_used('shell::rc')) {
       $self->debug && $self->log->debug("brik_init: load rc file");
 
-      my $cmd = $context->run('shell::rc', 'load');
-      for (@$cmd) {
-         $shell->cmd($_);
-      }
+      my $lines = $context->run('shell::rc', 'load');
+      $shell->cmdloop($lines);
    }
 
    $self->debug && $self->log->debug("brik_init: done");
@@ -66,31 +64,10 @@ sub load {
    }
 
    my @lines = ();
-   my @multilines = ();
    open(my $in, '<', $file)
          or return $self->log->error("load: can't open file [$file]: $!");
-   while (defined(my $this = <$in>)) {
-      chomp($this);
-      next if ($this =~ /^\s*#/);  # Skip comments
-      next if ($this =~ /^\s*$/);  # Skip blank lines
-
-      push @multilines, $this;
-
-      # First line of a multiline
-      if ($this =~ /\\\s*$/) {
-         next;
-      }
-
-      # Multiline edition finished, we can remove the `\' char before joining
-      for (@multilines) {
-         s/\\\s*$//;
-      }
-
-      $self->debug && $self->log->debug("load: multilines[@multilines]");
-
-      my $line = join('', @multilines);
-      @multilines = ();
-
+   while (defined(my $line = <$in>)) {
+      chomp($line);
       push @lines, $line;
    }
    close($in);
@@ -115,12 +92,7 @@ sub exec {
    my $context = $self->context;
    my $shell = $self->shell;
 
-   for (@$lines) {
-      if (/^\s*exit\s*(\d+)\s*;/) {
-         exit($1);
-      }
-      $shell->cmd($_);
-   }
+   $shell->cmdloop($lines);
 
    return 1;
 }
